@@ -127,7 +127,7 @@ macro_rules! gen_keypair {
 
 /// Generate a ntrulpr653 keypair
 pub fn keypair() -> (PublicKey, SecretKey) {
-    #[cfg(all(enable_avx2, feature = "avx2"))]
+    #[cfg(all(enable_x86_avx2, feature = "avx2"))]
     {
         if std::is_x86_feature_detected!("avx2") {
             return gen_keypair!(PQCLEAN_NTRULPR653_AVX2_crypto_kem_keypair);
@@ -150,7 +150,7 @@ macro_rules! encap {
 
 /// Encapsulate to a ntrulpr653 public key
 pub fn encapsulate(pk: &PublicKey) -> (SharedSecret, Ciphertext) {
-    #[cfg(all(enable_avx2, feature = "avx2"))]
+    #[cfg(all(enable_x86_avx2, feature = "avx2"))]
     {
         if std::is_x86_feature_detected!("avx2") {
             return encap!(PQCLEAN_NTRULPR653_AVX2_crypto_kem_enc, pk);
@@ -172,7 +172,7 @@ macro_rules! decap {
 
 /// Decapsulate the received ntrulpr653 ciphertext
 pub fn decapsulate(ct: &Ciphertext, sk: &SecretKey) -> SharedSecret {
-    #[cfg(all(enable_avx2, feature = "avx2"))]
+    #[cfg(all(enable_x86_avx2, feature = "avx2"))]
     {
         if std::is_x86_feature_detected!("avx2") {
             return decap!(PQCLEAN_NTRULPR653_AVX2_crypto_kem_dec, ct, sk);
